SystemOrganization addCategory: #'ConfigurationOfGofer'!

Object subclass: #ConfigurationOfGofer
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfGofer'!

!ConfigurationOfGofer class methodsFor: 'private' stamp: 'DaleHenrichs 1/25/2010 13:14'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfGofer class methodsFor: 'private' stamp: 'DaleHenrichs 1/25/2010 13:14'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfGofer class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 1/25/2010 13:14'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfGofer class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 1/25/2010 13:14'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfGofer class methodsFor: 'loading' stamp: 'DaleHenrichs 1/25/2010 13:14'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfGofer class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 1/25/2010 13:14'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfGofer class methodsFor: 'accessing' stamp: 'DaleHenrichs 1/25/2010 13:14'!
project

	^self new project! !

!ConfigurationOfGofer methodsFor: 'baselines' stamp: 'DaleHenrichs 02/11/2010 10:21'!
baseline100: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			package: 'Gofer-Core';
			package: 'Gofer-Tests' with: [ spec requires: 'Gofer-Core' ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Gofer-Core');
			group: 'Tests' with: #('Gofer-Tests'). ].
	spec for: #pharo do: [
		spec 
			repository: 'http://www.squeaksource.com/Pharo';
			repository: 'http://seaside.gemstone.com/ss/metacello'. ].
	spec for: #squeak do: [
		spec repository: 'http://seaside.gemstone.com/ss/metacello'. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/metacello'. ].! !

!ConfigurationOfGofer methodsFor: 'accessing' stamp: 'DaleHenrichs 02/19/2010 12:41'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		"use atomic load on GemStone to resolve some loading issues"
		Smalltalk at: #SystemVersion ifAbsent: [ project loadType: #atomic ]. 
		project ]! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 1/26/2010 09:58'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/25/2010 14:19'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-lr.116';
			package: 'Gofer-Tests' with: 'Gofer-Tests-lr.115' ].
	spec for: #pharo do: [].! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 2/19/2010 11:48'!
version101: spec
	<version: '1.0.1' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- use MethodReference>>methodSymbol for portability'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '02/11/10 10:22:48'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-DaleHenrichs.117';
			package: 'Gofer-Tests' with: 'Gofer-Tests-lr.115'.].! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 3/23/2010 14:47'!
version102: spec
	<version: '1.0.2' imports: #('1.0-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- pick up most recent gofer code
  - updated class comments
  - another comment fix
  - added http://squeaksource.blueplane.jp/ as a well known repository
  - repository priorities were used in the wrong order (thanks to Dale Henrichs)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/5/2010 09:32'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-dkh.121';
			package: 'Gofer-Tests' with: 'Gofer-Tests-lr.116'.].! !
